==> jc-1.4.0.tar.gz: soot/util/HashChain__24LinkIterator.h <==
// class soot.util.HashChain$LinkIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 202ab5e8f2334c5e soot_util_HashChain__24LinkIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_HashChain__24LinkIterator_H_
#define _JC_soot_util_HashChain__24LinkIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_util_HashChain$object;
struct _jc_soot_util_HashChain__24Link$object;

// Typedefs
typedef struct _jc_soot_util_HashChain__24LinkIterator$sub_refs	_jc_soot_util_HashChain__24LinkIterator$sub_refs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs	_jc_soot_util_HashChain__24LinkIterator$sub_nonrefs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$refs	_jc_soot_util_HashChain__24LinkIterator$refs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$nonrefs	_jc_soot_util_HashChain__24LinkIterator$nonrefs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$object	_jc_soot_util_HashChain__24LinkIterator$object;

typedef const struct _jc_soot_util_HashChain__24LinkIterator$vmethods	_jc_soot_util_HashChain__24LinkIterator$vmethods;
typedef const struct _jc_soot_util_HashChain__24LinkIterator$vtable	_jc_soot_util_HashChain__24LinkIterator$vtable;
typedef const struct _jc_soot_util_HashChain__24LinkIterator$vtype	_jc_soot_util_HashChain__24LinkIterator$vtype;

// Constructors
extern void _jc_soot_util_HashChain__24LinkIterator$method$_init$5087e156132826d3(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_util_HashChain__24LinkIterator$method$_init$d58d8cdc6e687c29(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_util_HashChain__24LinkIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_HashChain__24LinkIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
extern void _jc_soot_util_HashChain__24LinkIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_HashChain__24LinkIterator$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_HashChain__24LinkIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *);
};

// Vtable
struct _jc_soot_util_HashChain__24LinkIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_HashChain__24LinkIterator$vmethods	soot_util_HashChain__24LinkIterator;
};

// Vtype
struct _jc_soot_util_HashChain__24LinkIterator$vtype {
	_jc_type			type;
	_jc_soot_util_HashChain__24LinkIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_HashChain__24LinkIterator$sub_refs {
	struct _jc_soot_util_HashChain__24Link$object	*currentLink;
	struct _jc_java_lang_Object$object	*destination;
	struct _jc_soot_util_HashChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_HashChain__24LinkIterator$refs {
    _jc_soot_util_HashChain__24LinkIterator$sub_refs	soot_util_HashChain__24LinkIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs {
	jboolean	state;
	jboolean	stop;
	jlong	iteratorStateCount;
};

// Non-reference instance fields (object)
struct _jc_soot_util_HashChain__24LinkIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs	soot_util_HashChain__24LinkIterator;
};

// Object instance structure
struct _jc_soot_util_HashChain__24LinkIterator$object {
	_jc_soot_util_HashChain__24LinkIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_HashChain__24LinkIterator$vtype	*vtype;
	_jc_soot_util_HashChain__24LinkIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_HashChain__24LinkIterator$vtype _jc_soot_util_HashChain__24LinkIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_HashChain__24LinkIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_HashChain__24LinkIterator$class_object;

#endif	/* _JC_soot_util_HashChain__24LinkIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/HashChain__24LinkIterator.h <==
// class soot.util.HashChain$LinkIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 202ab5e8f2334c5e soot_util_HashChain__24LinkIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_HashChain__24LinkIterator_H_
#define _JC_soot_util_HashChain__24LinkIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_util_HashChain$object;
struct _jc_soot_util_HashChain__24Link$object;

// Typedefs
typedef struct _jc_soot_util_HashChain__24LinkIterator$sub_refs	_jc_soot_util_HashChain__24LinkIterator$sub_refs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs	_jc_soot_util_HashChain__24LinkIterator$sub_nonrefs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$refs	_jc_soot_util_HashChain__24LinkIterator$refs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$nonrefs	_jc_soot_util_HashChain__24LinkIterator$nonrefs;
typedef struct _jc_soot_util_HashChain__24LinkIterator$object	_jc_soot_util_HashChain__24LinkIterator$object;

typedef const struct _jc_soot_util_HashChain__24LinkIterator$vmethods	_jc_soot_util_HashChain__24LinkIterator$vmethods;
typedef const struct _jc_soot_util_HashChain__24LinkIterator$vtable	_jc_soot_util_HashChain__24LinkIterator$vtable;
typedef const struct _jc_soot_util_HashChain__24LinkIterator$vtype	_jc_soot_util_HashChain__24LinkIterator$vtype;

// Constructors
extern void _jc_soot_util_HashChain__24LinkIterator$method$_init$5087e156132826d3(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_HashChain__24LinkIterator$method$_init$d58d8cdc6e687c29(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_HashChain__24LinkIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_HashChain__24LinkIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_HashChain__24LinkIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_HashChain__24LinkIterator$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_HashChain__24LinkIterator$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_HashChain__24LinkIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_HashChain__24LinkIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_HashChain__24LinkIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_HashChain__24LinkIterator$vmethods	soot_util_HashChain__24LinkIterator;
};

// Vtype
struct _jc_soot_util_HashChain__24LinkIterator$vtype {
	_jc_type			type;
	_jc_soot_util_HashChain__24LinkIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_HashChain__24LinkIterator$sub_refs {
	struct _jc_soot_util_HashChain__24Link$object	*currentLink;
	struct _jc_java_lang_Object$object	*destination;
	struct _jc_soot_util_HashChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_HashChain__24LinkIterator$refs {
    _jc_soot_util_HashChain__24LinkIterator$sub_refs	soot_util_HashChain__24LinkIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs {
	jboolean	state;
	jboolean	stop;
	jlong	iteratorStateCount;
};

// Non-reference instance fields (object)
struct _jc_soot_util_HashChain__24LinkIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_HashChain__24LinkIterator$sub_nonrefs	soot_util_HashChain__24LinkIterator;
};

// Object instance structure
struct _jc_soot_util_HashChain__24LinkIterator$object {
	_jc_soot_util_HashChain__24LinkIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_HashChain__24LinkIterator$vtype	*vtype;
	_jc_soot_util_HashChain__24LinkIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_HashChain__24LinkIterator$vtype _jc_soot_util_HashChain__24LinkIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_HashChain__24LinkIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_HashChain__24LinkIterator$class_object;

#endif	/* _JC_soot_util_HashChain__24LinkIterator_H_ */
